@@ -138,7 +138,7 @@ pref("calendar.threading.latency ", 250);
 pref("calendar.network.multirealm", false);
 
 // Set up user agent
-pref("calendar.useragent.extra", "Lightning/4.7.5.1");
+pref("calendar.useragent.extra", "Lightning/4.7.6");
 
 // Disable use of system colors in minimonth and calendar views
 pref("calendar.view.useSystemColors", false);
@@ -148,9 +148,9 @@ pref("calendar.view.useSystemColors", false);
 pref("calendar.filter.maxiterations", 50);
 
 // Backend to use. false: libical, true: ical.js
-//@line 154 "/var/tmp/portage/mail-client/thunderbird-45.5.1/work/thunderbird-45.5.1/calendar/lightning/content/lightning.js"
+//@line 154 "/var/tmp/portage/mail-client/thunderbird-45.6.0/work/thunderbird-45.6.0/calendar/lightning/content/lightning.js"
 pref("calendar.icaljs", false);
-//@line 156 "/var/tmp/portage/mail-client/thunderbird-45.5.1/work/thunderbird-45.5.1/calendar/lightning/content/lightning.js"
+//@line 156 "/var/tmp/portage/mail-client/thunderbird-45.6.0/work/thunderbird-45.6.0/calendar/lightning/content/lightning.js"
 
 // Calendar integration notification
 pref("calendar.integration.notify", true);
